@@ -168,7 +168,9 @@ void KalendarAlarmClient::storeNotification(AlarmNotification *notification)
     KConfigGroup notificationGroup(&suspendedGroup, notification->uid());
     notificationGroup.writeEntry("UID", notification->uid());
     notificationGroup.writeEntry("Text", notification->text());
-    notificationGroup.writeEntry("Occurrence", notification->occurrence());
+    if (notification->occurrence().isValid()) {
+        notificationGroup.writeEntry("Occurrence", notification->occurrence());
+    }
     notificationGroup.writeEntry("RemindAt", notification->remindAt());
     KSharedConfig::openConfig()->sync();
 }
@@ -249,8 +251,12 @@ void KalendarAlarmClient::checkAlarms()
         const QString uid = alarm->parentUid();
 #endif
         const auto incidence = mCalendar->incidence(uid);
-        const auto occurrence = occurrenceForAlarm(incidence, alarm, from);
-        addNotification(uid, alarm->text(), occurrence, mLastChecked);
+        if (incidence) {
+            const auto occurrence = occurrenceForAlarm(incidence, alarm, from);
+            addNotification(uid, alarm->text(), occurrence, mLastChecked);
+        } else {
+            qCDebug(Log) << "Alarm points" << alarm << "to an nonexisting incidence" << uid;
+        }
     }
 
     // execute or update active alarms
