@@ -9,8 +9,12 @@
 #include <KCalendarCore/Attendee>
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 namespace Akonadi
 {
+class CalFilterPartStatusProxyModelPrivate;
+
 class CalFilterPartStatusProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -29,8 +33,7 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<CalFilterPartStatusProxyModelPrivate> const d;
 
     //@endcond
 private Q_SLOTS:
